@@ -22,6 +22,7 @@ use super::prelude::*;
 
 pub const RULE_HORIZONTAL_RULE: Rule = Rule {
     name: "horizontal-rule",
+    position: LineRequirement::StartOfLine,
     try_consume_fn,
 };
 
@@ -31,11 +32,8 @@ fn try_consume_fn<'p, 'r, 't>(
 ) -> ParseResult<'r, 't, Elements<'t>> {
     debug!(log, "Consuming token to create a horizontal rule");
 
-    // Optionally consume newline after
     check_step(parser, Token::TripleDash)?;
-    if parser.current().token == Token::LineBreak {
-        parser.step()?;
-    }
+    parser.get_optional_line_break()?;
 
     ok!(Element::HorizontalRule)
 }
