@@ -19,10 +19,11 @@
  */
 
 use super::prelude::*;
-use crate::tree::LinkLabel;
+use crate::tree::{LinkLabel, LinkLocation};
 
 pub const RULE_URL: Rule = Rule {
     name: "url",
+    position: LineRequirement::Any,
     try_consume_fn,
 };
 
@@ -32,8 +33,11 @@ fn try_consume_fn<'p, 'r, 't>(
 ) -> ParseResult<'r, 't, Elements<'t>> {
     debug!(log, "Consuming token as a URL");
 
+    let token = parser.current();
+    let url = cow!(token.slice);
+
     let element = Element::Link {
-        url: cow!(parser.current().slice),
+        link: LinkLocation::Url(url),
         label: LinkLabel::Url(None),
         target: None,
     };
